// Copyright 2023 Woodpecker Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package plugin

import (
	"github.com/urfave/cli/v3"
)

// Metadata defines runtime metadata.
type Metadata struct {
	Repository     Repository `json:"repo,omitempty"`
	Pipeline       Pipeline   `json:"curr,omitempty"`
	Commit         Commit     `json:"commit,omitempty"`
	PreviousCommit Commit     `json:"previous_commit,omitempty"`
	Step           Step       `json:"step,omitempty"`
	System         System     `json:"sys,omitempty"`
	Forge          Forge      `json:"forge,omitempty"`

	// Deprecated: Please use Commit instead.
	Curr Commit

	// Deprecated: Please use PreviousCommit instead.
	Prev Commit `json:"prev,omitempty"`
}

// MetadataFromContext creates a Metadata from the cli.Context.
func MetadataFromContext(c *cli.Command) Metadata {
	commit := commitFromContext(c)
	previousCommit := previousCommitFromContext(c)

	return Metadata{
		Repository:     repositoryFromContext(c),
		Pipeline:       pipelineFromContext(c),
		Commit:         commit,
		PreviousCommit: previousCommit,
		Step:           stepFromContext(c),
		System:         systemFromContext(c),
		Forge:          forgeFromContext(c),

		Curr: commit,
		Prev: previousCommit,
	}
}
